@@ -38,6 +38,8 @@ class Config(object):
     ishttps = False
     #是否开启证书校验
     isverify = True
+    #keep-alive 配置
+    keepalive = False
 
     # 是否断点续传
     upload_id = ''
